@@ -54,7 +54,10 @@ def _post(url, headers, data=None, files=None):
     try:
         headers['user-agent'] = 'WCS-Python-SDK-4.0.0(http://wcs.chinanetcenter.com)'
         #headers['Expect'] = '100-conitnue'
-        r = requests.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=True)
+        if cfg.isverify:
+            r = requests.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=True)
+        else:
+            r = requests.post(url=url, data=data, files=files, headers=headers, timeout=timeout, verify=False)
     except Exception as e:
         return -1,e,'Null'
     return __return_wrapper(r)
@@ -65,7 +68,10 @@ def _get(url, headers=None):
     try:
         headers = headers or {}
         headers['user-agent'] = 'WCS-Python-SDK-4.0.0(http://wcs.chinanetcenter.com)'
-        r = requests.get(url, headers=headers, timeout=timeout, verify=True)
+        if cfg.isverify:
+            r = requests.get(url, headers=headers, timeout=timeout, verify=True)
+        else:
+            r = requests.get(url, headers=headers, timeout=timeout, verify=False)
     except Exception as e:
         return -1,e,'Null'
     return __return_wrapper(r)
