@@ -1,3 +1,6 @@
+#!/usr/bin/python
+## -*- coding: utf-8 -*-
+
 from wcs.services.mgrbase import MgrBase
 from wcs.commons.config import Config
 from wcs.commons.http import _post
@@ -9,7 +12,9 @@ from wcs.commons.logme import debug, error
 MGR_URL = Config.mgr_url
 
 class PersistentFop(MgrBase):
-
+    """音视频持久化操作类
+    该类继承自mgrbase
+    """
     def __init__(self,auth,url):
         super(PersistentFop, self).__init__(auth,url)
       
